# Orchestrator

Evaluation orchestrators for local, async, and distributed execution.

## Base

### Orchestrator

::: rotalabs_eval.orchestrator.base.Orchestrator
    options:
      show_source: true

## Local

### LocalOrchestrator

::: rotalabs_eval.orchestrator.local.LocalOrchestrator
    options:
      show_source: true

## Async

### AsyncExecutor

::: rotalabs_eval.orchestrator.async_executor.AsyncExecutor
    options:
      show_source: true

!!! note "Distributed Orchestrators"
    Spark, Dask, and Ray orchestrators are available as stubs for future implementation.
